Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(294)

Unified Diff: media/base/video_renderer_sink.h

Issue 1996763002: Make painting a single frame a permanent API on VideoRendererSink. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Comments. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/null_video_sink_unittest.cc ('k') | media/blink/video_frame_compositor.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/video_renderer_sink.h
diff --git a/media/base/video_renderer_sink.h b/media/base/video_renderer_sink.h
index 9dd62d87e6af3e00c8c63c221856d66ea76e3a6a..f8e64bfc19f27946708e9af9efee6575bfef022c 100644
--- a/media/base/video_renderer_sink.h
+++ b/media/base/video_renderer_sink.h
@@ -53,16 +53,12 @@ class MEDIA_EXPORT VideoRendererSink {
// liberally if no new frames are expected.
virtual void Stop() = 0;
- // Instead of using a callback driven rendering path, allow clients to paint
- // frames as they see fit without regard for the compositor.
- // TODO(dalecurtis): This should be nuked once experiments show the new path
- // is amazing and the old path is not! http://crbug.com/439548
- virtual void PaintFrameUsingOldRenderingPath(
- const scoped_refptr<VideoFrame>& frame) = 0;
-
- // TODO(dalecurtis): We may need OnSizeChanged() and OnOpacityChanged()
- // methods on this interface if background rendering is handled inside of
- // the media layer instead of by VideoFrameCompositor.
+ // Instead of using a callback driven rendering path, allow clients to paint a
+ // single frame as they see fit without regard for the compositor; this is
+ // useful for painting poster images or hole frames without having to issue a
+ // Start() -> Render() -> Stop(). Clients are free to mix usage of Render()
+ // based painting and PaintSingleFrame().
+ virtual void PaintSingleFrame(const scoped_refptr<VideoFrame>& frame) = 0;
virtual ~VideoRendererSink() {}
};
« no previous file with comments | « media/base/null_video_sink_unittest.cc ('k') | media/blink/video_frame_compositor.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698